// src/index.ts
var RegShakuDirectiveUnderlineSolid = /^(?<leadingSpaces>\s*)(?<content>-+)\s*$/;
var RegShakuDirectiveUnderlineWavy = /^(?<leadingSpaces>\s*)(?<content>~+)\s*$/;
var RegShakuDirectiveUnderlineDotted = /^(?<leadingSpaces>\s*)(?<content>\.+)\s*$/;
var RegShakuAnnotationLine = /^(?<leadingSpaces>\s*)\[(?<content>.+)\]\s*$/;
var RegShakuDirectiveCallout = /^(?<leadingSpaces>\s*)\^\s*$/;
var RegShakuDirectiveCollapse = /^(?<leadingSpaces>\s*)@collapse\s+(?<mark>\S+)\s*$/;
var RegShakuDirectiveHighlight = /^(?<leadingSpaces>\s*)@highlight(\s+(?<mark>(\S+)?)\s*)?$/;
var parseLine = (line) => {
  var _a, _b, _c, _d, _e, _f, _g, _h, _i, _j, _k, _l;
  const matchShakuDirectiveUnderlineSolid = line.match(
    RegShakuDirectiveUnderlineSolid
  );
  if (matchShakuDirectiveUnderlineSolid) {
    return {
      type: "DirectiveUnderline",
      config: {
        offset: ((_a = matchShakuDirectiveUnderlineSolid.groups) == null ? void 0 : _a.leadingSpaces.length) ?? 0,
        content: ((_b = matchShakuDirectiveUnderlineSolid.groups) == null ? void 0 : _b.content) ?? "",
        style: "solid"
      }
    };
  }
  const matchShakuDirectiveUnderlineWavy = line.match(
    RegShakuDirectiveUnderlineWavy
  );
  if (matchShakuDirectiveUnderlineWavy) {
    return {
      type: "DirectiveUnderline",
      config: {
        offset: ((_c = matchShakuDirectiveUnderlineWavy.groups) == null ? void 0 : _c.leadingSpaces.length) ?? 0,
        content: ((_d = matchShakuDirectiveUnderlineWavy.groups) == null ? void 0 : _d.content) ?? "",
        style: "wavy"
      }
    };
  }
  const matchShakuDirectiveUnderlineDotted = line.match(
    RegShakuDirectiveUnderlineDotted
  );
  if (matchShakuDirectiveUnderlineDotted) {
    return {
      type: "DirectiveUnderline",
      config: {
        offset: ((_e = matchShakuDirectiveUnderlineDotted.groups) == null ? void 0 : _e.leadingSpaces.length) ?? 0,
        content: ((_f = matchShakuDirectiveUnderlineDotted.groups) == null ? void 0 : _f.content) ?? "",
        style: "dotted"
      }
    };
  }
  const matchShakuAnnotationLine = line.match(RegShakuAnnotationLine);
  if (matchShakuAnnotationLine) {
    return {
      type: "AnnotationLine",
      config: {
        offset: ((_g = matchShakuAnnotationLine.groups) == null ? void 0 : _g.leadingSpaces.length) ?? 0,
        content: ((_h = matchShakuAnnotationLine.groups) == null ? void 0 : _h.content) ?? ""
      }
    };
  }
  const matchShakuDirectiveCallout = line.match(RegShakuDirectiveCallout);
  if (matchShakuDirectiveCallout) {
    return {
      type: "DirectiveCallout",
      config: {
        offset: ((_i = matchShakuDirectiveCallout.groups) == null ? void 0 : _i.leadingSpaces.length) ?? 0
      }
    };
  }
  const matchShakuDirectiveCollapse = line.match(RegShakuDirectiveCollapse);
  if (matchShakuDirectiveCollapse) {
    const mark = (_j = matchShakuDirectiveCollapse.groups) == null ? void 0 : _j.mark;
    if (mark !== "start" && mark !== "end") {
      throw new Error(`mark: ${mark} is not supported under @collapose`);
    }
    return {
      type: "DirectiveCollapse",
      config: {
        offset: ((_k = matchShakuDirectiveCollapse.groups) == null ? void 0 : _k.leadingSpaces.length) ?? 0,
        mark
      }
    };
  }
  const matchShakuDirectiveHighlight = line.match(RegShakuDirectiveHighlight);
  if (matchShakuDirectiveHighlight) {
    const mark = ((_l = matchShakuDirectiveHighlight.groups) == null ? void 0 : _l.mark) || "below";
    if (mark !== "start" && mark !== "end" && mark !== "below") {
      throw new Error(`mark: ${mark} is not supported under @highlight`);
    }
    return {
      type: "DirectiveHighlight",
      config: {
        mark
      }
    };
  }
  return null;
};
function shouldApplyAnnotation(meta) {
  return /\bannotate\b/.test(meta);
}
function renderComponent(component) {
  switch (component.type) {
    case "ShakuComponentCallout":
      return `<div class="shaku-callout" style="left:${component.config.offset}ch"><span class="shaku-callout-arrow" style="left:${component.config.arrowOffset}ch"></span>${component.config.contents.map(escapeHtml).join("\n")}</div>`;
    case "ShakuComponentUnderline":
      return `<div class="shaku-underline shaku-underline-${component.config.underlineStyle}" style="left:${component.config.offset}ch"><span class="shaku-underline-line" style="left:${component.config.underlineOffset}ch">${component.config.underlineContent}</span>${component.config.contents.map(escapeHtml).join("\n")}</div>`;
    default:
      assertsNever(component);
  }
}
function assertsNever(data) {
  throw new Error("expected never but got: " + data);
}
function escapeHtml(html) {
  return html.replace(/</g, "&lt;").replace(/>/g, "&gt;");
}
export {
  parseLine,
  renderComponent,
  shouldApplyAnnotation
};
